@@ -1,14 +1,22 @@
-package Pcore::Handle::sqlite;    ## no critic qw[NamingConventions::Capitalization]
+package Pcore::Handle::sqlite;
 
-use Pcore -class;
+use Pcore -class, -const;
 use DBD::SQLite;
+use DBD::SQLite::Constants qw[:file_open];
+use Pcore::DBH::SQLite;
 
 # NOTE http://habrahabr.ru/post/149635/
 # для вставки данных в цикле надо использовать h->begin_work ... h->commit
 
 with qw[Pcore::DBH];
 
-has mode => ( is => 'ro', isa => Enum [qw[R RW RWC]], default => 'RWC' );    # READONLY, READWRITE, READWRITE + CREATE
+const our $SQLITE_OPEN_FLAGS => {
+    RO  => SQLITE_OPEN_READONLY | SQLITE_OPEN_SHAREDCACHE,
+    RW  => SQLITE_OPEN_READWRITE | SQLITE_OPEN_SHAREDCACHE,
+    RWC => SQLITE_OPEN_READWRITE | SQLITE_OPEN_CREATE | SQLITE_OPEN_SHAREDCACHE,
+};
+
+has mode => ( is => 'ro', isa => Enum [ keys $SQLITE_OPEN_FLAGS->%* ], default => 'RWC' );
 has busy_timeout => ( is => 'ro', isa => PositiveOrZeroInt, default => 1_000 * 3 );    # milliseconds, set to 0 to disable timeout, default - 3 seconds
 
 # SQLITE PRAGMAS
@@ -21,8 +29,8 @@ has foreign_keys => ( is => 'ro', isa => Bool, default => 1 );
 sub BUILD ( $self, $args ) {
     my $attr = P->hash->merge(
         $self->default_dbi_attr,
-        {   sqlite_open_flags => $self->mode eq 'R' ? DBD::SQLite::OPEN_READONLY : $self->mode eq 'RW' ? DBD::SQLite::OPEN_READWRITE : DBD::SQLite::OPEN_READWRITE | DBD::SQLite::OPEN_CREATE,
-            sqlite_unicode => 1,
+        {   sqlite_open_flags                => $SQLITE_OPEN_FLAGS->{ $self->mode },
+            sqlite_unicode                   => 1,
             sqlite_allow_multiple_statements => 1,
             sqlite_use_immediate_transaction => 1,
             sqlite_see_if_its_a_number       => 1,
@@ -40,7 +48,15 @@ sub BUILD ( $self, $args ) {
     $self->{_dbh}->do( 'PRAGMA cache_size = ' . $self->cache_size );
     $self->{_dbh}->do( 'PRAGMA foreign_keys = ' . $self->foreign_keys );
 
-    $self->{_dbh}->sqlite_busy_timeout( $self->busy_timeout );
+    $self->_on_connect($self);
+
+    return;
+}
+
+sub _on_connect ( $self, $dbh ) {
+    $dbh->{_dbh}->sqlite_busy_timeout( $self->busy_timeout );
+
+    $self->on_connect->($dbh) if $self->on_connect;
 
     return;
 }
@@ -169,9 +185,9 @@ sub do {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 67                   | Subroutines::ProhibitExcessComplexity - Subroutine "do" with high complexity score (25)                        |
+## |    3 | 83                   | Subroutines::ProhibitExcessComplexity - Subroutine "do" with high complexity score (25)                        |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 117                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
+## |    3 | 133                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -186,6 +202,16 @@ Pcore::Handle::sqlite
 
 =head1 SYNOPSIS
 
+    my $dbh = P->handle(
+        "sqlite:db.sqlite",
+        max_conn   => 10,
+        on_connect => sub ($dbh) {
+            $dbh->attach( 'db1', 'db1.sqlite' );
+
+            return;
+        }
+    );
+
 =head1 DESCRIPTION
 
 =cut
